{{/*
   _labels.tpl
   This file defines common Kubernetes labels for resources.
   These labels follow the recommended conventions and can be reused across different templates.
   The function `common.labels.standard` returns a set of standard labels.
*/}}

{{/*
   Generate standard Kubernetes labels for a resource.
   It includes the app name, release name, version, component, part-of, managed-by, and Helm chart info.
   Uses the naming helpers from _naming.tpl to generate consistent names and handle truncation.
*/}}
{{- define "common.labels.standard" -}}
app.kubernetes.io/name: {{ include "common.names.fullname" . }}
app.kubernetes.io/instance: {{ .Release.Name | quote }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
app.kubernetes.io/component: {{ .Values.component | default (.Chart.Name) | quote }}
app.kubernetes.io/part-of: {{ .Values.partOf | default "cta" | quote }}
app.kubernetes.io/managed-by: {{ .Release.Service | quote }}
helm.sh/chart: {{ printf "%s-%s" .Chart.Name .Chart.Version | quote }}
{{- end }}

{{/*
   Generate standard Kubernetes labels for a resource without the name.
   It includes the app, release name, version, component, part-of, managed-by, and Helm chart info.
   Uses the naming helpers from _naming.tpl to generate consistent names and handle truncation.
*/}}
{{- define "common.labels.withoutname" -}}
app.kubernetes.io/instance: {{ .Release.Name | quote }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
app.kubernetes.io/component: {{ .Values.component | default (.Chart.Name) | quote }}
app.kubernetes.io/part-of: {{ .Values.partOf | default "cta" | quote }}
app.kubernetes.io/managed-by: {{ .Release.Service | quote }}
helm.sh/chart: {{ printf "%s-%s" .Chart.Name .Chart.Version | quote }}
{{- end }}

{{/*
   Generate labels for a specific resource where a full name is needed.
   This label set uses the full name generated by the common.names.fullname helper.
*/}}
{{- define "common.labels.withfullname" -}}
app.kubernetes.io/name: {{ include "common.names.fullname" . }}
app.kubernetes.io/instance: {{ .Release.Name | quote }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
app.kubernetes.io/component: {{ .Values.component | default (.Chart.Name) | quote }}
app.kubernetes.io/part-of: {{ .Values.partOf | default "cta" | quote }}
app.kubernetes.io/managed-by: {{ .Release.Service | quote }}
helm.sh/chart: {{ printf "%s-%s" .Chart.Name .Chart.Version | quote }}
{{- end }}
